Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(252)

Unified Diff: ash/common/system/web_notification/ash_popup_alignment_delegate.h

Issue 2103603002: mash: Remove StatusAreaWidget references from system tray classes (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: review comments, rename SetSystemTrayHeight to SetTrayBubbleHeight Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/ash.gyp ('k') | ash/common/system/web_notification/ash_popup_alignment_delegate.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/system/web_notification/ash_popup_alignment_delegate.h
diff --git a/ash/system/web_notification/ash_popup_alignment_delegate.h b/ash/common/system/web_notification/ash_popup_alignment_delegate.h
similarity index 82%
rename from ash/system/web_notification/ash_popup_alignment_delegate.h
rename to ash/common/system/web_notification/ash_popup_alignment_delegate.h
index 7d1f2f49c7e6595d30efc1c741c2fd1134587ee6..95d80aa13cbf857b61702d08e420175bec4b3db7 100644
--- a/ash/system/web_notification/ash_popup_alignment_delegate.h
+++ b/ash/common/system/web_notification/ash_popup_alignment_delegate.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef ASH_SYSTEM_WEB_NOTIFICATION_ASH_POPUP_ALIGNMENT_DELEGATE_H_
-#define ASH_SYSTEM_WEB_NOTIFICATION_ASH_POPUP_ALIGNMENT_DELEGATE_H_
+#ifndef ASH_COMMON_SYSTEM_WEB_NOTIFICATION_ASH_POPUP_ALIGNMENT_DELEGATE_H_
+#define ASH_COMMON_SYSTEM_WEB_NOTIFICATION_ASH_POPUP_ALIGNMENT_DELEGATE_H_
#include <stdint.h>
@@ -41,12 +41,12 @@ class ASH_EXPORT AshPopupAlignmentDelegate
// Start observing the system.
void StartObserving(display::Screen* screen, const display::Display& display);
- // Sets the current height of the system tray so that the notification toasts
- // can avoid it.
- void SetSystemTrayHeight(int height);
+ // Sets the current height of the system tray bubble (or legacy notification
+ // bubble) so that web notification toasts can avoid it.
+ void SetTrayBubbleHeight(int height);
- // Returns the current system tray height.
- int system_tray_height_for_test() const { return system_tray_height_; }
+ // Returns the current tray bubble height or 0 if there is no bubble.
+ int tray_bubble_height_for_test() const { return tray_bubble_height_; }
// Overridden from message_center::PopupAlignmentDelegate:
int GetToastOriginX(const gfx::Rect& toast_bounds) const override;
@@ -88,11 +88,11 @@ class ASH_EXPORT AshPopupAlignmentDelegate
display::Screen* screen_;
gfx::Rect work_area_;
WmShelf* shelf_;
- int system_tray_height_;
+ int tray_bubble_height_;
DISALLOW_COPY_AND_ASSIGN(AshPopupAlignmentDelegate);
};
} // namespace ash
-#endif // ASH_SYSTEM_WEB_NOTIFICATION_ASH_POPUP_ALIGNMENT_DELEGATE_H_
+#endif // ASH_COMMON_SYSTEM_WEB_NOTIFICATION_ASH_POPUP_ALIGNMENT_DELEGATE_H_
« no previous file with comments | « ash/ash.gyp ('k') | ash/common/system/web_notification/ash_popup_alignment_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698